@@ -1,11 +1,22 @@
 #!/usr/bin/env perl
 #
+# This file is part of POE-Component-Client-MPD
+#
+# This software is copyright (c) 2007 by Jerome Quelin.
+#
+# This is free software; you can redistribute it and/or modify it under
+# the same terms as the Perl 5 programming language system itself.
+#
+#
 
 use warnings;
 use strict;
 
-use lib 'lib';
-use POE qw{ Component::Client::MPD };
+use FindBin qw{ $Bin };
+use lib "$Bin/../lib";
+
+use POE;
+use POE::Component::Client::MPD;
 
 POE::Component::Client::MPD->spawn( {alias => 'mpd'} );
 POE::Session->create(
